package com.exotest.http2;

import android.net.Uri;
import android.os.Bundle;
import android.util.Log;

import androidx.appcompat.app.AppCompatActivity;

import com.google.android.exoplayer2.ExoPlayerFactory;
import com.google.android.exoplayer2.SimpleExoPlayer;
import com.google.android.exoplayer2.ext.okhttp.OkHttpDataSourceFactory;
import com.google.android.exoplayer2.source.MediaSource;
import com.google.android.exoplayer2.source.hls.HlsMediaSource;
import com.google.android.exoplayer2.ui.PlayerView;
import com.google.android.exoplayer2.upstream.DataSource;

import java.io.IOException;
import java.net.InetSocketAddress;
import java.net.Proxy;
import java.util.Collections;

import okhttp3.CacheControl;
import okhttp3.Call;
import okhttp3.EventListener;
import okhttp3.OkHttpClient;
import okhttp3.Protocol;

public class MainActivity extends AppCompatActivity {

    private static final String TAG = "MainActivity";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        final PlayerView playerView = new PlayerView(this);
        final SimpleExoPlayer player = ExoPlayerFactory.newSimpleInstance(this);
        playerView.setPlayer(player);

        final OkHttpClient client = new OkHttpClient.Builder()
                .eventListener(new EventListener() {
                    @Override
                    public void connectEnd(Call call, InetSocketAddress inetSocketAddress, Proxy proxy, Protocol protocol) {
                        Log.d(TAG, "okhttp connected protocol=" + protocol);
                    }

                    @Override
                    public void callFailed(Call call, IOException ioe) {
                        Log.d(TAG, "okhttp callFailed " + ioe);
                    }
                })
                // Uncomment the "protocols" below to forbid http/2
//                .protocols(Collections.singletonList(Protocol.HTTP_1_1))
                .build();


        DataSource.Factory dataSourceFactory = new OkHttpDataSourceFactory(client, null, (CacheControl) null);

        MediaSource videoSource = new HlsMediaSource.Factory(dataSourceFactory)
                .createMediaSource(Uri.parse("https://noamtamim.com/hls/sintel1/master.m3u8"));

        Log.d(TAG, "okhttp3 userAgent: " + okhttp3.internal.Version.userAgent());

        player.prepare(videoSource);
        player.setPlayWhenReady(true);

        setContentView(playerView);
    }
}
